Module invite

Module invite 

Structures related to a Discord invite.

Structs

CreateInviteOptions
Represents data that is sent to the create invite endpoint.
Invite
Represents a code that when used, adds a user to a guild or group DM channel.
InviteMetadata
Detailed information about an invite.
PartialInvite
Represents a partial channel invite.