Structures related to a Discord invite.
Structs
- Create
Invite Options - Represents data that is sent to the create invite endpoint.
- Invite
- Represents a code that when used, adds a user to a guild or group DM channel.
- Invite
Metadata - Detailed information about an invite.
- Partial
Invite - Represents a partial channel invite.